/* -*- mode: C++; indent-tabs-mode: nil; fill-column: 100; c-basic-offset: 4; -*-
 *
 * Copyright (C) 1996 Tim Witham <twitham@pcocd2.intel.com>
 *
 * (see the files README and COPYING for more details)
 *
 * file variables and routines available outside of file.c
 *
 */

void handle_opt(char opt, char *optarg);

void writefile(char *filename);

void readfile(char *filename);
